@@ -14,15 +14,17 @@ from libmidi.utils.bytes import get_data_from_bytes
 class Chunk:
 	"""
 	Class representing a MIDI chunk.
-	
+
 	A MIDI chunk is a sequence of bytes that starts with a 4-byte
 	string, followed by a 32-bit integer representing the size of the following data.
 	"""
 	def __init__(self, name: bytes, data: bytes):
+		"""Initialize a chunk."""
 		self.name = name
 		self.data = data
 
-	def __str__(self):
+	def __str__(self) -> str:
+		"""Return a string representation of the chunk."""
 		return f"Chunk(name={self.name}, length={self.get_length()})"
 
 	@classmethod
@@ -35,7 +37,7 @@ class Chunk:
 		return Chunk(name, chunk_data), remaining_data
 
 	@classmethod
-	def from_stream(cls, buffer: BufferedReader):
+	def from_stream(cls, buffer: BufferedReader) -> 'Chunk':
 		"""Read a chunk from a stream."""
 		name, length = struct.unpack('>4sL', buffer.read(8))
 		data = buffer.read(length)
